# dv-launcher

This is a launcher made for automating the deployment of odoo docker containers.

## Usage
See help:
```
dv-launcher --help
```
Config Odoo to use all available cpus and ram:
```
dv-launcher config auto-config
```
Launch Odoo. (You need to bee in a valid odoo directory):
```
dv-launcher
```
